import { Component, Host, h, Event, Prop, Watch } from '@stencil/core';
/**
 * A switch component which follows Dyte's Design System.
 */
export class DyteSwitch {
  constructor() {
    /** Whether the switch is enabled/checked */
    this.checked = false;
    /** Whether switch is readonly */
    this.readonly = false;
    /** Whether switch is readonly */
    this.disabled = false;
    this.onClick = () => {
      if (!this.readonly && !this.disabled) {
        this.checked = !this.checked;
      }
    };
    this.onKeyPress = (e) => {
      if (this.readonly)
        return;
      switch (e.key) {
        // Enter or Space
        case 'Enter':
        case ' ':
          this.checked = !this.checked;
          break;
      }
    };
  }
  checkedChange(checked) {
    this.dyteChange.emit(checked);
  }
  render() {
    return (h(Host, { role: "switch", tabIndex: this.disabled && 0, "aria-readonly": this.readonly, "aria-checked": this.checked, "aria-disabled": this.disabled, class: { checked: this.checked }, onClick: this.onClick, onKeyPress: this.onKeyPress },
      h("div", { class: "switch", part: "switch" })));
  }
  static get is() { return "dyte-switch"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-switch.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-switch.css"]
  }; }
  static get properties() { return {
    "checked": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the switch is enabled/checked"
      },
      "attribute": "checked",
      "reflect": false,
      "defaultValue": "false"
    },
    "readonly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether switch is readonly"
      },
      "attribute": "readonly",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether switch is readonly"
      },
      "attribute": "disabled",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "dyteChange",
      "name": "dyteChange",
      "bubbles": true,
      "cancelable": false,
      "composed": false,
      "docs": {
        "tags": [],
        "text": "Event when switch value is changed"
      },
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "checked",
      "methodName": "checkedChange"
    }]; }
}
