import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { r as requestFullScreen, e as exitFullSreen, i as isFullScreenSupported, a as isFullScreenEnabled } from './full-screen.js';
import { d as defineCustomElement$4 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$3 } from './dyte-icon2.js';
import { d as defineCustomElement$2 } from './dyte-spinner2.js';

const dyteFullscreenToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const DyteFullscreenToggle$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.fullScreenActive = false;
    this.isFullScreenSupported = true;
    this.toggleFullScreen = () => {
      const fullScreenElement = document.querySelector('dyte-meeting');
      if (!fullScreenElement)
        return;
      if (!this.fullScreenActive) {
        requestFullScreen(fullScreenElement);
        this.fullScreenActive = true;
      }
      else {
        exitFullSreen();
        this.fullScreenActive = false;
      }
    };
  }
  connectedCallback() {
    this.isFullScreenSupported = isFullScreenSupported();
    this.handleFullScreenChange = () => {
      this.fullScreenActive = isFullScreenEnabled();
    };
    window.addEventListener('webkitfullscreenchange', this.handleFullScreenChange);
    window.addEventListener('fullscreenchange', this.handleFullScreenChange);
  }
  disconnectedCallback() {
    window.removeEventListener('webkitfullscreenchange', this.handleFullScreenChange);
    window.removeEventListener('fullscreenchange', this.handleFullScreenChange);
  }
  render() {
    if (!this.isFullScreenSupported) {
      return null;
    }
    return (h(Host, { title: this.t('Fullscreen') }, h("dyte-controlbar-button", { size: this.size, iconPack: this.iconPack, onClick: this.toggleFullScreen, icon: this.fullScreenActive
        ? this.iconPack.full_screen_minimize
        : this.iconPack.full_screen_maximize, label: this.t('Fullscreen'), variant: this.variant })));
  }
  static get style() { return dyteFullscreenToggleCss; }
}, [1, "dyte-fullscreen-toggle", {
    "variant": [513],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "fullScreenActive": [32],
    "isFullScreenSupported": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-fullscreen-toggle", "dyte-controlbar-button", "dyte-icon", "dyte-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-fullscreen-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteFullscreenToggle$1);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteFullscreenToggle = DyteFullscreenToggle$1;
const defineCustomElement = defineCustomElement$1;

export { DyteFullscreenToggle, defineCustomElement };
