import { r as registerInstance, c as createEvent, h, H as Host } from './index-74ddb327.js';
import { d as defaultIconPack } from './default-icon-pack-eabba256.js';
import { u as useLanguage } from './index-a214afbc.js';
import { R as Render } from './index-f7bdca7a.js';
import { d as defaultConfig } from './default-ui-config-c5d610a7.js';
import { s as state, o as onChange } from './store-79928517.js';
import { i as isV2Theme } from './versionTwoApis-e31e770d.js';
import './default-language-04851639.js';

const dyteSidebarCss = ":host{position:relative;box-sizing:border-box;display:flex;width:100%;max-width:var(--dyte-space-80, 320px);flex-direction:column;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));font-family:var(--dyte-font-family, sans-serif);color:rgb(var(--dyte-colors-text-1000, 255 255 255));overflow:hidden}.close{position:absolute;top:var(--dyte-space-3, 12px);left:var(--dyte-space-3, 12px)}.title{margin:var(--dyte-space-0, 0px);margin-top:var(--dyte-space-3, 12px);margin-bottom:var(--dyte-space-3, 12px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;text-align:center;font-size:16px;font-weight:400}#mobile-header{margin-top:var(--dyte-space-2, 8px);display:flex;align-items:center;justify-content:space-evenly;border-bottom:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}#mobile-header dyte-button{border-bottom:var(--dyte-border-width-md, 2px) solid transparent;border-radius:var(--dyte-border-radius-none, 0)}#mobile-header dyte-button:hover{background-color:transparent}#mobile-header dyte-button.active{border-color:rgb(var(--dyte-colors-brand-400, 53 110 253))}dyte-chat,dyte-participants,dyte-plugins{flex:1}:host([view='sidebar']){margin-left:var(--dyte-space-2, 8px);margin-right:var(--dyte-space-2, 8px);border-radius:var(--dyte-border-radius-lg, 12px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity))}:host([view='full-screen']){position:absolute;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);z-index:50;max-width:100%;border:none}";

const DyteSidebar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Enabled sections in sidebar */
    this.enabledSections = [
      'chat',
      'polls',
      'participants',
      'plugins',
    ];
    /** Default section */
    this.defaultSection = 'chat';
    /** Config */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    /** View type */
    this.view = 'default';
    this.tab = this.defaultSection;
    this.close = () => {
      this.stateUpdate.emit({ activeSidebar: false, sidebar: this.defaultSection });
      state.sidebar = this.tab;
    };
  }
  connectedCallback() {
    this.viewChanged(this.view);
    this.statesChanged(this.states);
    onChange('sidebar', () => this.statesChanged());
  }
  disconnectedCallback() {
    this.keydownListener && document.removeEventListener('keydown', this.keydownListener);
  }
  statesChanged(s) {
    const states = s || state;
    if ((states === null || states === void 0 ? void 0 : states.sidebar) != null) {
      this.tab = states.sidebar;
    }
  }
  viewChanged(view) {
    if (view === 'full-screen') {
      this.keydownListener = (e) => {
        if (e.key === 'Escape') {
          this.close();
        }
      };
      document.addEventListener('keydown', this.keydownListener);
    }
  }
  filterSections(sections) {
    if (!this.meeting.self.suggestedTheme)
      return sections;
    if (isV2Theme(this.meeting.self.suggestedTheme))
      return sections;
    const theme = this.meeting.self.suggestedTheme;
    if (!theme.controlBar.elements.chat) {
      sections = sections.filter((item) => item !== 'chat');
    }
    else if (!theme.controlBar.elements.polls) {
      sections = sections.filter((item) => item !== 'polls');
    }
    else if (!theme.controlBar.elements.plugins) {
      sections = sections.filter((item) => item !== 'plugins');
    }
    else if (!theme.controlBar.elements.participants) {
      sections = sections.filter((item) => item !== 'participants');
    }
    return sections;
  }
  viewSection(section) {
    this.tab = section;
    this.stateUpdate.emit({ activeSidebar: true, sidebar: this.tab });
    state.activeSidebar = true;
    state.sidebar = this.tab;
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states || state,
      size: this.size,
      t: this.t,
      iconPack: this.iconPack,
    };
    return (h(Host, null, this.view === 'full-screen' && [
      h("h3", { class: "title" }, this.t('About Call')),
      h("div", { id: "mobile-header" }, this.filterSections(this.enabledSections).map((section) => (h("dyte-button", { key: section, variant: "ghost", class: { active: this.tab === section }, onClick: () => this.viewSection(section) }, this.t(section))))),
    ], h("dyte-button", { variant: "ghost", kind: "icon", class: "close", onClick: this.close, "aria-label": this.t('Close') }, h("dyte-icon", { icon: this.iconPack.dismiss })), this.view !== 'full-screen' && h("h3", { class: "title" }, this.t(this.tab)), this.tab === 'chat' && h(Render, { element: "dyte-chat", defaults: defaults }), this.tab === 'polls' && h(Render, { element: "dyte-polls", defaults: defaults }), this.tab === 'participants' && h(Render, { element: "dyte-participants", defaults: defaults }), this.tab === 'plugins' && h(Render, { element: "dyte-plugins", defaults: defaults })));
  }
  static get watchers() { return {
    "states": ["statesChanged"],
    "view": ["viewChanged"]
  }; }
};
DyteSidebar.style = dyteSidebarCss;

export { DyteSidebar as dyte_sidebar };
